==> vtk-9.1.0-21-x86_64.pkg.tar.zst: usr/lib/python3.10/site-packages/vtkmodules/all.py <==
""" This module loads the entire VTK library into its namespace.  It
also allows one to use specific packages inside the vtk directory.."""

from __future__ import absolute_import

# --------------------------------------
from .vtkCommonCore import *
from .vtkWebCore import *
from .vtkCommonMath import *
from .vtkCommonTransforms import *
from .vtkCommonDataModel import *
from .vtkCommonExecutionModel import *
from .vtkIOCore import *
from .vtkImagingCore import *
from .vtkIOImage import *
from .vtkIOXMLParser import *
from .vtkIOXML import *
from .vtkCommonMisc import *
from .vtkFiltersCore import *
from .vtkRenderingCore import *
from .vtkRenderingContext2D import *
from .vtkRenderingFreeType import *
from .vtkRenderingSceneGraph import *
from .vtkRenderingVtkJS import *
from .vtkIOExport import *
from .vtkWebGLExporter import *
from .vtkFiltersGeneral import *
from .vtkRenderingUI import *
from .vtkRenderingOpenGL2 import *
from .vtkFiltersSources import *
from .vtkInteractionWidgets import *
from .vtkViewsCore import *
from .vtkInteractionStyle import *
from .vtkViewsInfovis import *
from .vtkCommonComputationalGeometry import *
from .vtkCommonSystem import *
from .vtkIOLegacy import *
from .vtkDomainsChemistry import *
from .vtkRenderingContextOpenGL2 import *
from .vtkRenderingVolume import *
from .vtkImagingMath import *
from .vtkRenderingVolumeOpenGL2 import *
from .vtkViewsContext2D import *
from .vtkTestingRendering import *
from .vtkInteractionImage import *
from .vtkRenderingRayTracing import *
from .vtkRenderingVolumeAMR import *
from .vtkRenderingLabel import *
from .vtkRenderingQt import *
from .vtkPythonContext2D import *
from .vtkParallelCore import *
from .vtkParallelMPI import *
from .vtkRenderingLICOpenGL2 import *
from .vtkRenderingParallelLIC import *
from .vtkRenderingParallel import *
from .vtkRenderingVR import *
from .vtkRenderingOpenVR import *
from .vtkRenderingMatplotlib import *
from .vtkRenderingLOD import *
from .vtkRenderingImage import *
from .vtkIOMovie import *
from .vtkIOVideo import *
from .vtkIOFFMPEG import *
from .vtkRenderingFFMPEGOpenGL2 import *
from .vtkRenderingExternal import *
from .vtkParallelMPI4Py import *
from .vtkIOXdmf2 import *
from .vtkIOVeraOut import *
from .vtkIOVPIC import *
from .vtkIOTecplotTable import *
from .vtkIOTRUCHAS import *
from .vtkIOSegY import *
from .vtkIOSQL import *
from .vtkIOPostgreSQL import *
from .vtkIOXdmf3 import *
from .vtkIOParallelXdmf3 import *
from .vtkIOParallelXML import *
from .vtkIONetCDF import *
from .vtkIOParallelNetCDF import *
from .vtkIOLSDyna import *
from .vtkIOParallelLSDyna import *
from .vtkIOExodus import *
from .vtkIOParallelExodus import *
from .vtkIOPLY import *
from .vtkIOPIO import *
from .vtkIOPDAL import *
from .vtkIOOpenVDB import *
from .vtkIOOggTheora import *
from .vtkIOOMF import *
from .vtkIOODBC import *
from .vtkIOMySQL import *
from .vtkIOMotionFX import *
from .vtkIOGeometry import *
from .vtkIOParallel import *
from .vtkIOMPIParallel import *
from .vtkIOMPIImage import *
from .vtkIOMINC import *
from .vtkIOLAS import *
from .vtkIOInfovis import *
from .vtkIOImport import *
from .vtkIOIOSS import *
from .vtkIOHDF import *
from .vtkIOH5part import *
from .vtkIOH5Rage import *
from .vtkIOGeoJSON import *
from .vtkIOFides import *
from .vtkIOExportPDF import *
from .vtkRenderingGL2PSOpenGL2 import *
from .vtkIOExportGL2PS import *
from .vtkIOEnSight import *
from .vtkIOCityGML import *
from .vtkIOChemistry import *
from .vtkIOCONVERGECFD import *
from .vtkIOCGNSReader import *
from .vtkIOAsynchronous import *
from .vtkIOAMR import *
from .vtkIOADIOS2 import *
from .vtkInfovisBoostGraphAlgorithms import *
from .vtkImagingStencil import *
from .vtkImagingStatistics import *
from .vtkImagingGeneral import *
from .vtkImagingOpenGL2 import *
from .vtkImagingMorphological import *
from .vtkImagingFourier import *
from .vtkIOGDAL import *
from .vtkGeovisGDAL import *
from .vtkCommonColor import *
from .vtkImagingSources import *
from .vtkInfovisCore import *
from .vtkGeovisCore import *
from .vtkInfovisLayout import *
from .vtkRenderingAnnotation import *
from .vtkImagingHybrid import *
from .vtkImagingColor import *
from .vtkFiltersTopology import *
from .vtkFiltersSelection import *
from .vtkFiltersSMP import *
from .vtkFiltersReebGraph import *
from .vtkFiltersPython import *
from .vtkFiltersProgrammable import *
from .vtkFiltersModeling import *
from .vtkFiltersPoints import *
from .vtkFiltersVerdict import *
from .vtkFiltersParallelVerdict import *
from .vtkFiltersStatistics import *
from .vtkFiltersParallelStatistics import *
from .vtkFiltersImaging import *
from .vtkFiltersExtraction import *
from .vtkFiltersGeometry import *
from .vtkFiltersHybrid import *
from .vtkFiltersTexture import *
from .vtkFiltersParallel import *
from .vtkFiltersParallelImaging import *
from .vtkFiltersParallelGeometry import *
from .vtkFiltersFlowPaths import *
from .vtkFiltersParallelFlowPaths import *
from .vtkFiltersParallelDIY2 import *
from .vtkFiltersHyperTree import *
from .vtkFiltersGeneric import *
from .vtkFiltersAMR import *
from .vtkDomainsParallelChemistry import *
from .vtkFiltersParallelMPI import *
from .vtkDomainsChemistryOpenGL2 import *
from .vtkCommonPython import *
from .vtkCommonArchive import *
from .vtkChartsCore import *
from .vtkAcceleratorsVTKmCore import *
from .vtkAcceleratorsVTKmDataModel import *
from .vtkAcceleratorsVTKmFilters import *


# useful macro for getting type names
from .util.vtkConstants import vtkImageScalarTypeNameMacro

# import convenience decorators
from .util.misc import calldata_type

# import the vtkVariant helpers
from .util.vtkVariant import *

==> vtk-9.2.6-8-x86_64.pkg.tar.zst: usr/lib/python3.11/site-packages/vtkmodules/all.py <==
""" This module loads the entire VTK library into its namespace.  It
also allows one to use specific packages inside the vtk directory.."""

from __future__ import absolute_import

# --------------------------------------
from .vtkCommonCore import *
from .vtkWebCore import *
from .vtkCommonMath import *
from .vtkCommonTransforms import *
from .vtkCommonDataModel import *
from .vtkCommonExecutionModel import *
from .vtkIOCore import *
from .vtkImagingCore import *
from .vtkIOImage import *
from .vtkIOXMLParser import *
from .vtkIOXML import *
from .vtkCommonMisc import *
from .vtkFiltersCore import *
from .vtkRenderingCore import *
from .vtkRenderingContext2D import *
from .vtkRenderingFreeType import *
from .vtkRenderingSceneGraph import *
from .vtkRenderingVtkJS import *
from .vtkIOExport import *
from .vtkWebGLExporter import *
from .vtkFiltersGeneral import *
from .vtkRenderingHyperTreeGrid import *
from .vtkRenderingUI import *
from .vtkRenderingOpenGL2 import *
from .vtkFiltersSources import *
from .vtkInteractionWidgets import *
from .vtkViewsCore import *
from .vtkInteractionStyle import *
from .vtkViewsInfovis import *
from .vtkCommonComputationalGeometry import *
from .vtkCommonSystem import *
from .vtkIOLegacy import *
from .vtkDomainsChemistry import *
from .vtkRenderingContextOpenGL2 import *
from .vtkRenderingVolume import *
from .vtkImagingMath import *
from .vtkRenderingVolumeOpenGL2 import *
from .vtkViewsContext2D import *
from .vtkTestingRendering import *
from .vtkInteractionImage import *
from .vtkRenderingRayTracing import *
from .vtkRenderingVolumeAMR import *
from .vtkRenderingLabel import *
from .vtkRenderingQt import *
from .vtkPythonContext2D import *
from .vtkParallelCore import *
from .vtkParallelMPI import *
from .vtkRenderingLICOpenGL2 import *
from .vtkRenderingParallelLIC import *
from .vtkRenderingParallel import *
from .vtkRenderingVR import *
from .vtkRenderingOpenXR import *
from .vtkRenderingOpenVR import *
from .vtkRenderingMatplotlib import *
from .vtkRenderingLOD import *
from .vtkRenderingImage import *
from .vtkIOMovie import *
from .vtkIOVideo import *
from .vtkIOFFMPEG import *
from .vtkRenderingFFMPEGOpenGL2 import *
from .vtkRenderingExternal import *
from .vtkParallelMPI4Py import *
from .vtkIOXdmf2 import *
from .vtkIOVeraOut import *
from .vtkIOVPIC import *
from .vtkIOTecplotTable import *
from .vtkIOTRUCHAS import *
from .vtkIOSegY import *
from .vtkIOSQL import *
from .vtkIOPostgreSQL import *
from .vtkIOXdmf3 import *
from .vtkIOParallelXdmf3 import *
from .vtkIOParallelXML import *
from .vtkIONetCDF import *
from .vtkIOParallelNetCDF import *
from .vtkIOLSDyna import *
from .vtkIOParallelLSDyna import *
from .vtkIOExodus import *
from .vtkIOParallelExodus import *
from .vtkIOPLY import *
from .vtkIOPIO import *
from .vtkIOPDAL import *
from .vtkIOOpenVDB import *
from .vtkIOOggTheora import *
from .vtkIOOMF import *
from .vtkIOODBC import *
from .vtkIOMySQL import *
from .vtkIOMotionFX import *
from .vtkIOGeometry import *
from .vtkIOParallel import *
from .vtkIOMPIParallel import *
from .vtkIOMPIImage import *
from .vtkIOMINC import *
from .vtkIOLAS import *
from .vtkIOInfovis import *
from .vtkIOImport import *
from .vtkIOIOSS import *
from .vtkIOH5part import *
from .vtkIOH5Rage import *
from .vtkIOGeoJSON import *
from .vtkIOFides import *
from .vtkIOExportPDF import *
from .vtkRenderingGL2PSOpenGL2 import *
from .vtkIOExportGL2PS import *
from .vtkIOEnSight import *
from .vtkIOCityGML import *
from .vtkIOChemistry import *
from .vtkIOCesium3DTiles import *
from .vtkIOCONVERGECFD import *
from .vtkIOHDF import *
from .vtkIOCGNSReader import *
from .vtkIOAsynchronous import *
from .vtkIOAMR import *
from .vtkIOADIOS2 import *
from .vtkInfovisBoostGraphAlgorithms import *
from .vtkImagingStencil import *
from .vtkImagingStatistics import *
from .vtkImagingGeneral import *
from .vtkImagingOpenGL2 import *
from .vtkImagingMorphological import *
from .vtkImagingFourier import *
from .vtkIOGDAL import *
from .vtkGeovisGDAL import *
from .vtkCommonColor import *
from .vtkImagingSources import *
from .vtkInfovisCore import *
from .vtkGeovisCore import *
from .vtkInfovisLayout import *
from .vtkRenderingAnnotation import *
from .vtkImagingHybrid import *
from .vtkImagingColor import *
from .vtkFiltersTopology import *
from .vtkFiltersSelection import *
from .vtkFiltersSMP import *
from .vtkFiltersReebGraph import *
from .vtkFiltersPython import *
from .vtkFiltersProgrammable import *
from .vtkFiltersModeling import *
from .vtkFiltersPoints import *
from .vtkFiltersVerdict import *
from .vtkFiltersParallelVerdict import *
from .vtkFiltersStatistics import *
from .vtkFiltersParallelStatistics import *
from .vtkFiltersImaging import *
from .vtkFiltersExtraction import *
from .vtkFiltersGeometry import *
from .vtkFiltersHybrid import *
from .vtkFiltersTexture import *
from .vtkFiltersParallel import *
from .vtkFiltersParallelImaging import *
from .vtkFiltersParallelGeometry import *
from .vtkFiltersFlowPaths import *
from .vtkFiltersParallelFlowPaths import *
from .vtkFiltersParallelDIY2 import *
from .vtkFiltersGeneric import *
from .vtkFiltersAMR import *
from .vtkDomainsParallelChemistry import *
from .vtkFiltersParallelMPI import *
from .vtkDomainsChemistryOpenGL2 import *
from .vtkFiltersHyperTree import *
from .vtkCommonPython import *
from .vtkCommonArchive import *
from .vtkChartsCore import *
from .vtkAcceleratorsVTKmCore import *
from .vtkAcceleratorsVTKmDataModel import *
from .vtkAcceleratorsVTKmFilters import *


# useful macro for getting type names
from .util.vtkConstants import vtkImageScalarTypeNameMacro

# import convenience decorators
from .util.misc import calldata_type

# import the vtkVariant helpers
from .util.vtkVariant import *
